Class: Killbill::Plugin::PluginBase

Inherits:
Object
  • Object
show all
Defined in:
lib/killbill/plugin.rb

Direct Known Subclasses

Notification

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize ⇒ PluginBase

Called by the Killbill lifecycle when instantiating the plugin



32
33
34
# File 'lib/killbill/plugin.rb', line 32

def initialize()
  @active = false
end

Instance Attribute Details

#active ⇒ Object (readonly)

Returns the value of attribute active.



11
12
13
# File 'lib/killbill/plugin.rb', line 11

def active
  @active
end

#clock ⇒ Object

Extra services



24
25
26
# File 'lib/killbill/plugin.rb', line 24

def clock
  @clock
end

#conf_dir ⇒ Object

Extra services



24
25
26
# File 'lib/killbill/plugin.rb', line 24

def conf_dir
  @conf_dir
end

#kb_apis ⇒ Object

Extra services



24
25
26
# File 'lib/killbill/plugin.rb', line 24

def kb_apis
  @kb_apis
end

#logger ⇒ Object

Extra services



24
25
26
# File 'lib/killbill/plugin.rb', line 24

def logger
  @logger
end

#plugin_name ⇒ Object

Extra services



24
25
26
# File 'lib/killbill/plugin.rb', line 24

def plugin_name
  @plugin_name
end

#root ⇒ Object

Extra services



24
25
26
# File 'lib/killbill/plugin.rb', line 24

def root
  @root
end

Instance Method Details

#after_request ⇒ Object

Will be called by each thread before returning to Killbill



48
49
# File 'lib/killbill/plugin.rb', line 48

def after_request
end

#start_plugin ⇒ Object

Called by the Killbill lifecycle when initializing the plugin



14
15
16
# File 'lib/killbill/plugin.rb', line 14

def start_plugin
  @active = true
end

#stop_plugin ⇒ Object

Called by the Killbill lifecycle when stopping the plugin



19
20
21
# File 'lib/killbill/plugin.rb', line 19

def stop_plugin
  @active = false
end